Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrPrintedError = errors.New("terminating because of errors")
ErrPrintedError indicates error messages have been printed directly to stderr, and can be used so that the returned error itself isn't printed as well.
Functions ¶
Types ¶
type Command ¶
type Command struct {
// The currently active command.
*cobra.Command
// contains filtered or unexported fields
}
type Stats ¶ added in v0.6.0
type Stats struct {
// CUE groups stats obtained from the CUE evaluator.
CUE stats.Counts
// Go groups stats obtained from the Go runtime via [runtime.ReadMemStats].
Go struct {
AllocBytes uint64
AllocObjects uint64
}
// Proc groups stats obtained from the current OS process via calls like [syscall.Getrusage].
Proc procStats
}
Stats expands stats.Counts with counters obtained from other sources, such as the Go runtime. The stats are grouped by category to clarify their source.
Source Files
¶
- add.go
- cmd.go
- common.go
- completion.go
- custom.go
- def.go
- eval.go
- exp.go
- experiments_help_gen.go
- export.go
- fix.go
- flags.go
- fmt.go
- get.go
- get_crd.go
- get_go.go
- help.go
- import.go
- login.go
- lsp.go
- mod.go
- modedit.go
- modfix.go
- modget.go
- modinit.go
- modmirror.go
- modpublish.go
- modregistry.go
- modrename.go
- modresolve.go
- modtidy.go
- modupgrade.go
- orphans.go
- refactor.go
- refactor_imports.go
- registry.go
- root.go
- stats_unix.go
- trim.go
- version.go
- vet.go
Click to show internal directories.
Click to hide internal directories.